@@ -19,8 +19,6 @@ except:
 import hildon
 import osso
 import conic
-import dbus
-import dbus.glib
 
 from gnome import gconf
 import threading
